v5.0.1
======

Packaging refresh.

v5.0.0
======

Require Python 3.8 or later.

4.0
===

Dropped support for Amazon FPS. A new payment system will need to
be implemented if RecaptureDocs is to be revived.

Use virtualenv and pip for installing the service.
